# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bmc/staff/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Bmc\\Staff\\": "packages/bmc/staff/src",
            "Bmc\\Staff\\Seeders\\": "packages/bmc/staff/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bmc\Staff\Providers\StaffServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Staff'  => Bmc\Staff\Facades\Staff::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bmc\\Staff\\Seeders\\StaffTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bmc\Staff\Providers\StaffServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bmc\Staff\Providers\StaffServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bmc\Staff\Providers\StaffServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/staff/{modulename}

**User**

    http://path-to-route-folder/user/staff/{modulename}

**Public**

    http://path-to-route-folder/staff


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/staff/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/staff/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/staff/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/staff/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/staff/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/staff/{modulename}/{slug}
    METHOD: GET