<?php

namespace Bmc\Staff\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Bmc\Staff\Interfaces\GalleriesRepositoryInterface;
use Bmc\Staff\Repositories\Eloquent\Filters\GalleriesPublicFilter;
use Bmc\Staff\Repositories\Eloquent\Presenters\GalleriesListPresenter;

class GalleriesPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        GalleriesRepositoryInterface $galleries
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('bmc.staff.modules'), 'galleries', guard_url('galleries'));
        $this->repository = $galleries;
    }

    /**
     * Show galleries's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(GalleriesPublicFilter::class)
            ->setPresenter(GalleriesListPresenter::class)
            ->select('galleries.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('staff::galleries.names'))
            ->view('staff::public.galleries.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show galleries.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('staff::galleries.name'))
            ->view('staff::public.galleries.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
