<?php

namespace Bmc\Staff\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bmc\Staff\Http\Requests\GalleriesRequest;
use Bmc\Staff\Models\Galleries;

/**
 * Admin web controller class.
 */
class GalleriesWorkflowController extends BaseController
{

    /**
     * Workflow controller function for galleries.
     *
     * @param Model   $galleries
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(GalleriesRequest $request, Galleries $galleries, $step)
    {

        try {

            $galleries->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('staff::galleries.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/galleries/galleries/' . $galleries->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/galleries/galleries/' . $galleries->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for galleries.
     *
     * @param Model   $galleries
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Galleries $galleries, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $galleries->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('staff::galleries.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('staff::admin.galleries.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('staff::admin.galleries.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('staff::admin.galleries.message', $data)->render();

        }

    }
}
