<?php

namespace Bmc\Staff\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Bmc\Staff\Models\Galleries;

class GalleriesPolicy
{

    /**
     * Determine if the given user can view the galleries.
     *
     * @param UserPolicyInterface $authUser
     * @param Galleries $galleries
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Galleries $galleries)
    {
        if ($authUser->canDo('staff.galleries.view') && $authUser->isAdmin()) {
            return true;
        }

        return $galleries->user_id == user_id() && $galleries->user_type == user_type();
    }

    /**
     * Determine if the given user can create a galleries.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('staff.galleries.create');
    }

    /**
     * Determine if the given user can update the given galleries.
     *
     * @param UserPolicyInterface $authUser
     * @param Galleries $galleries
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Galleries $galleries)
    {
        if ($authUser->canDo('staff.galleries.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $galleries->user_id == user_id() && $galleries->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given galleries.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Galleries $galleries)
    {
        return $galleries->user_id == user_id() && $galleries->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given galleries.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Galleries $galleries)
    {
        if ($authUser->canDo('staff.galleries.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given galleries.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Galleries $galleries)
    {
        if ($authUser->canDo('staff.galleries.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
