<?php

namespace Bmc\Staff\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Bmc\Staff\Models\Staff;

class StaffPolicy
{

    /**
     * Determine if the given user can view the staff.
     *
     * @param UserPolicyInterface $authUser
     * @param Staff $staff
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Staff $staff)
    {
        if ($authUser->canDo('staff.staff.view') && $authUser->isAdmin()) {
            return true;
        }

        return $staff->user_id == user_id() && $staff->user_type == user_type();
    }

    /**
     * Determine if the given user can create a staff.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('staff.staff.create');
    }

    /**
     * Determine if the given user can update the given staff.
     *
     * @param UserPolicyInterface $authUser
     * @param Staff $staff
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Staff $staff)
    {
        if ($authUser->canDo('staff.staff.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $staff->user_id == user_id() && $staff->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given staff.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Staff $staff)
    {
        return $staff->user_id == user_id() && $staff->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given staff.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Staff $staff)
    {
        if ($authUser->canDo('staff.staff.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given staff.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Staff $staff)
    {
        if ($authUser->canDo('staff.staff.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
