<?php

namespace Bmc\Staff\Providers;

use Illuminate\Support\ServiceProvider;
use Bmc\Staff\Staff;

class StaffServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'staff');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'staff');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Bmc\Staff\Providers\AuthServiceProvider::class);
        $this->app->register(\Bmc\Staff\Providers\RouteServiceProvider::class);
        // $this->app->register(\Bmc\Staff\Providers\EventServiceProvider::class);
        // $this->app->register(\Bmc\Staff\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bmc.staff', function($app)
        {
            return $this->app->make(Staff::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Staff to repository
        $this->app->bind(
            'Bmc\Staff\Interfaces\StaffRepositoryInterface',
            \Bmc\Staff\Repositories\Eloquent\StaffRepository::class
        );        // Bind Galleries to repository
        $this->app->bind(
            'Bmc\Staff\Interfaces\GalleriesRepositoryInterface',
            \Bmc\Staff\Repositories\Eloquent\GalleriesRepository::class
        );
    }


    /**
     * Merges user's and staff's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bmc.staff'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Bmc\Staff\Commands\Staff::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bmc.staff'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bmc/staff.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/staff')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/staff')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
