<?php

namespace Bmc\Staff\Workflow;

use Bmc\Staff\Models\Galleries;
use Validator;

class GalleriesValidator
{

    /**
     * Determine if the given galleries is valid for complete status.
     *
     * @param Galleries $galleries
     *
     * @return bool / Validator
     */
    public function complete(Galleries $galleries)
    {
        return Validator::make($galleries->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given galleries is valid for verify status.
     *
     * @param Galleries $galleries
     *
     * @return bool / Validator
     */
    public function verify(Galleries $galleries)
    {
        return Validator::make($galleries->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given galleries is valid for approve status.
     *
     * @param Galleries $galleries
     *
     * @return bool / Validator
     */
    public function approve(Galleries $galleries)
    {
        return Validator::make($galleries->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given galleries is valid for publish status.
     *
     * @param Galleries $galleries
     *
     * @return bool / Validator
     */
    public function publish(Galleries $galleries)
    {
        return Validator::make($galleries->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given galleries is valid for archive status.
     *
     * @param Galleries $galleries
     *
     * @return bool / Validator
     */
    public function archive(Galleries $galleries)
    {
        return Validator::make($galleries->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given galleries is valid for unpublish status.
     *
     * @param Galleries $galleries
     *
     * @return bool / Validator
     */
    public function unpublish(Galleries $galleries)
    {
        return Validator::make($galleries->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
